#ifndef _VECTOR3_CPP
#define _VECTOR3_CPP

#include <iostream>
#include <cmath>

#include "Vector3.h"

using namespace std;

//===========================  ============================

Vector3::Vector3( double ax, double ay, double az )
{  x = ax;  y = ay;  z = az;  }

//=========================   ===========================

Vector3& Vector3::operator+=( const Vector3& rhs )
{
   x += rhs.x;  y += rhs.y;  z += rhs.z;
   return *this;
} // Vector3::operator+=

Vector3& Vector3::operator-=( const Vector3& rhs )
{
   x -= rhs.x;  y -= rhs.y;  z -= rhs.z;
   return *this;
} // Vector3::operator-=

Vector3& Vector3::operator*=( double rhs )
{
   x *= rhs;  y *= rhs;  z *= rhs;
   return *this;
} // operator*=( const Vector3&

//======================   ======================

bool operator==( const Vector3& lhs, const Vector3& rhs )
{
   return (lhs.x == rhs.x) && (lhs.y == rhs.y) && (lhs.z == rhs.z);
} // operator==( const Vector3&

bool operator!=( const Vector3& lhs, const Vector3& rhs )
{
   return !(lhs == rhs);
} // operator!=( const Vector3&

Vector3 operator+( const Vector3& lhs, const Vector3& rhs )
{
   Vector3 fv( lhs );
   fv += rhs;
   return fv;
} // operator+( const Vector3&

Vector3 operator-( const Vector3& lhs, const Vector3& rhs )
{
   Vector3 fv( lhs );
   fv -= rhs;
   return fv;
} // operator-( const Vector3&

Vector3 operator*( double lhs, const Vector3& rhs )
{
   Vector3 fv( rhs );
   fv *= lhs;
   return fv;
} // operator*( const Vector3&
        
Vector3 operator*( const Vector3& lhs, double rhs )
{
   Vector3 fv( lhs );
   fv *= rhs;
   return fv;
} // operator*( const Vector3&
        
double operator*( const Vector3& lhs, const Vector3& rhs )
{
   return lhs.x*rhs.x + lhs.y*rhs.y + lhs.z*rhs.z;
} // operator*( const Vector3&

Vector3 operator^( const Vector3& lhs, const Vector3& rhs )
{
   Vector3 fv;
   fv.x = lhs.y*rhs.z - lhs.z*rhs.y;
   fv.y = rhs.x*lhs.z - rhs.z*lhs.x;
   fv.z = rhs.y*lhs.x - rhs.x*lhs.y;
   return fv;
} // operator^( const Vector3

ostream& operator<<( ostream& tout, const Vector3& rhs )
{
   return tout << "(" << rhs.x << ", " << rhs.y << ", " << rhs.z << ")";
} // operator<<

#endif // _VECTOR3_CPP
